
from setuptools import setup

setup(name="spotifylyrics",
	version="1.0",
	description="Displays lyrics for spotify songs",
	url="http://github.com",
	author="Yask Srivastava",
	author_email="yask123@gmail.com",
	license='MIT',
	packages=["spotifylyrics"],
	scripts=["bin/spotifylyrics"],
	zip_safe=False)
